@@ -11,8 +11,8 @@
 #    under the License.
 #
 
+from neutronclient.i18n import _
 from neutronclient.neutron import v2_0 as neutronV20
-from neutronclient.openstack.common.gettextutils import _
 
 
 class ListCredential(neutronV20.ListCommand):
