@@ -16,11 +16,12 @@
 
 import argparse
 
+from oslo.serialization import jsonutils
+
 from neutronclient.common import exceptions
 from neutronclient.common import utils
+from neutronclient.i18n import _
 from neutronclient.neutron import v2_0 as neutronV20
-from neutronclient.openstack.common.gettextutils import _
-from neutronclient.openstack.common import jsonutils
 
 
 def _format_fixed_ips(port):
@@ -30,11 +31,68 @@ def _format_fixed_ips(port):
         return ''
 
 
+def _format_fixed_ips_csv(port):
+    try:
+        return jsonutils.dumps(port['fixed_ips'])
+    except (TypeError, KeyError):
+        return ''
+
+
+def _add_updatable_args(parser):
+    parser.add_argument(
+        '--name',
+        help=_('Name of this port.'))
+    parser.add_argument(
+        '--fixed-ip', metavar='subnet_id=SUBNET,ip_address=IP_ADDR',
+        action='append',
+        help=_('Desired IP and/or subnet for this port: '
+               'subnet_id=<name_or_id>,ip_address=<ip>. '
+               'You can repeat this option.'))
+    parser.add_argument(
+        '--fixed_ip',
+        action='append',
+        help=argparse.SUPPRESS)
+    parser.add_argument(
+        '--device-id',
+        help=_('Device ID of this port.'))
+    parser.add_argument(
+        '--device_id',
+        help=argparse.SUPPRESS)
+    parser.add_argument(
+        '--device-owner',
+        help=_('Device owner of this port.'))
+    parser.add_argument(
+        '--device_owner',
+        help=argparse.SUPPRESS)
+
+
+def _updatable_args2body(parsed_args, body, client):
+    if parsed_args.device_id:
+        body['port'].update({'device_id': parsed_args.device_id})
+    if parsed_args.device_owner:
+        body['port'].update({'device_owner': parsed_args.device_owner})
+    if parsed_args.name:
+        body['port'].update({'name': parsed_args.name})
+    ips = []
+    if parsed_args.fixed_ip:
+        for ip_spec in parsed_args.fixed_ip:
+            ip_dict = utils.str2dict(ip_spec)
+            if 'subnet_id' in ip_dict:
+                subnet_name_id = ip_dict['subnet_id']
+                _subnet_id = neutronV20.find_resourceid_by_name_or_id(
+                    client, 'subnet', subnet_name_id)
+                ip_dict['subnet_id'] = _subnet_id
+            ips.append(ip_dict)
+    if ips:
+        body['port'].update({'fixed_ips': ips})
+
+
 class ListPort(neutronV20.ListCommand):
     """List ports that belong to a given tenant."""
 
     resource = 'port'
     _formatters = {'fixed_ips': _format_fixed_ips, }
+    _formatters_csv = {'fixed_ips': _format_fixed_ips_csv, }
     list_columns = ['id', 'name', 'mac_address', 'fixed_ips']
     pagination_support = True
     sorting_support = True
@@ -105,8 +163,8 @@ class UpdateExtraDhcpOptMixin(object):
             action='append',
             dest='extra_dhcp_opts',
             help=_('Extra dhcp options to be assigned to this port: '
-                   'opt_name=<dhcp_option_name>,opt_value=<value>. You can '
-                   'repeat this option.'))
+                   'opt_name=<dhcp_option_name>,opt_value=<value>,'
+                   'ip_version={4,6}. You can repeat this option.'))
 
     def args2body_extradhcpopt(self, parsed_args, port):
         ops = []
@@ -116,19 +174,17 @@ class UpdateExtraDhcpOptMixin(object):
             # both must be thrown out.
             opt_ele = {}
             edo_err_msg = _("Invalid --extra-dhcp-opt option, can only be: "
-                            "opt_name=<dhcp_option_name>,opt_value=<value>. "
+                            "opt_name=<dhcp_option_name>,opt_value=<value>,"
+                            "ip_version={4,6}. "
                             "You can repeat this option.")
             for opt in parsed_args.extra_dhcp_opts:
-                if opt.split('=')[0] in ['opt_value', 'opt_name']:
-                    opt_ele.update(utils.str2dict(opt))
-                    if (('opt_name' in opt_ele) and
-                        ('opt_value' in opt_ele)):
-                        if opt_ele['opt_value'] == 'null':
-                            opt_ele['opt_value'] = None
-                        ops.append(opt_ele)
-                        opt_ele = {}
-                    else:
-                        raise exceptions.CommandError(edo_err_msg)
+                opt_ele.update(utils.str2dict(opt))
+                if ('opt_name' in opt_ele and
+                        ('opt_value' in opt_ele or 'ip_version' in opt_ele)):
+                    if opt_ele.get('opt_value') == 'null':
+                        opt_ele['opt_value'] = None
+                    ops.append(opt_ele)
+                    opt_ele = {}
                 else:
                     raise exceptions.CommandError(edo_err_msg)
 
@@ -143,9 +199,7 @@ class CreatePort(neutronV20.CreateCommand, UpdatePortSecGroupMixin,
     resource = 'port'
 
     def add_known_arguments(self, parser):
-        parser.add_argument(
-            '--name',
-            help=_('Name of this port.'))
+        _add_updatable_args(parser)
         parser.add_argument(
             '--admin-state-down',
             dest='admin_state', action='store_false',
@@ -160,23 +214,6 @@ class CreatePort(neutronV20.CreateCommand, UpdatePortSecGroupMixin,
         parser.add_argument(
             '--mac_address',
             help=argparse.SUPPRESS)
-        parser.add_argument(
-            '--device-id',
-            help=_('Device ID of this port.'))
-        parser.add_argument(
-            '--device_id',
-            help=argparse.SUPPRESS)
-        parser.add_argument(
-            '--fixed-ip', metavar='subnet_id=SUBNET,ip_address=IP_ADDR',
-            action='append',
-            help=_('Desired IP and/or subnet for this port: '
-                   'subnet_id=<name_or_id>,ip_address=<ip>.'
-                   'You can repeat this option.'))
-        parser.add_argument(
-            '--fixed_ip',
-            action='append',
-            help=argparse.SUPPRESS)
-
         self.add_arguments_secgroup(parser)
         self.add_arguments_extradhcpopt(parser)
 
@@ -185,30 +222,16 @@ class CreatePort(neutronV20.CreateCommand, UpdatePortSecGroupMixin,
             help=_('Network ID or name this port belongs to.'))
 
     def args2body(self, parsed_args):
+        client = self.get_client()
         _network_id = neutronV20.find_resourceid_by_name_or_id(
-            self.get_client(), 'network', parsed_args.network_id)
+            client, 'network', parsed_args.network_id)
         body = {'port': {'admin_state_up': parsed_args.admin_state,
                          'network_id': _network_id, }, }
+        _updatable_args2body(parsed_args, body, client)
         if parsed_args.mac_address:
             body['port'].update({'mac_address': parsed_args.mac_address})
-        if parsed_args.device_id:
-            body['port'].update({'device_id': parsed_args.device_id})
         if parsed_args.tenant_id:
             body['port'].update({'tenant_id': parsed_args.tenant_id})
-        if parsed_args.name:
-            body['port'].update({'name': parsed_args.name})
-        ips = []
-        if parsed_args.fixed_ip:
-            for ip_spec in parsed_args.fixed_ip:
-                ip_dict = utils.str2dict(ip_spec)
-                if 'subnet_id' in ip_dict:
-                    subnet_name_id = ip_dict['subnet_id']
-                    _subnet_id = neutronV20.find_resourceid_by_name_or_id(
-                        self.get_client(), 'subnet', subnet_name_id)
-                    ip_dict['subnet_id'] = _subnet_id
-                ips.append(ip_dict)
-        if ips:
-            body['port'].update({'fixed_ips': ips})
 
         self.args2body_secgroup(parsed_args, body['port'])
         self.args2body_extradhcpopt(parsed_args, body['port'])
@@ -229,11 +252,25 @@ class UpdatePort(neutronV20.UpdateCommand, UpdatePortSecGroupMixin,
     resource = 'port'
 
     def add_known_arguments(self, parser):
+        _add_updatable_args(parser)
+        parser.add_argument(
+            '--admin-state-up',
+            choices=['True', 'False'],
+            help=_('Set admin state up for the port.'))
+        parser.add_argument(
+            '--admin_state_up',
+            choices=['True', 'False'],
+            help=argparse.SUPPRESS)
         self.add_arguments_secgroup(parser)
         self.add_arguments_extradhcpopt(parser)
 
     def args2body(self, parsed_args):
         body = {'port': {}}
+        client = self.get_client()
+        _updatable_args2body(parsed_args, body, client)
+        if parsed_args.admin_state_up:
+            body['port'].update({'admin_state_up':
+                                parsed_args.admin_state_up})
         self.args2body_secgroup(parsed_args, body['port'])
         self.args2body_extradhcpopt(parsed_args, body['port'])
         return body
