@@ -16,19 +16,16 @@
 # @author: Swaminathan Vasudevan, Hewlett-Packard.
 #
 
-import logging
-
 from neutronclient.common import utils
+from neutronclient.i18n import _
 from neutronclient.neutron import v2_0 as neutronv20
 from neutronclient.neutron.v2_0.vpn import utils as vpn_utils
-from neutronclient.openstack.common.gettextutils import _
 
 
 class ListIKEPolicy(neutronv20.ListCommand):
     """List IKE policies that belong to a tenant."""
 
     resource = 'ikepolicy'
-    log = logging.getLogger(__name__ + '.ListIKEPolicy')
     list_columns = ['id', 'name', 'auth_algorithm',
                     'encryption_algorithm', 'ike_version', 'pfs']
     _formatters = {}
@@ -40,14 +37,12 @@ class ShowIKEPolicy(neutronv20.ShowCommand):
     """Show information of a given IKE policy."""
 
     resource = 'ikepolicy'
-    log = logging.getLogger(__name__ + '.ShowIKEPolicy')
 
 
 class CreateIKEPolicy(neutronv20.CreateCommand):
     """Create an IKE policy."""
 
     resource = 'ikepolicy'
-    log = logging.getLogger(__name__ + '.CreateIKEPolicy')
 
     def add_known_arguments(self, parser):
         parser.add_argument(
@@ -60,10 +55,7 @@ class CreateIKEPolicy(neutronv20.CreateCommand):
                    'Default:sha1'))
         parser.add_argument(
             '--encryption-algorithm',
-            default='aes-128', choices=['3des',
-                                        'aes-128',
-                                        'aes-192',
-                                        'aes-256'],
+            default='aes-128',
             help=_('Encryption algorithm in lowercase, default:aes-128'))
         parser.add_argument(
             '--phase1-negotiation-mode',
@@ -111,7 +103,6 @@ class UpdateIKEPolicy(neutronv20.UpdateCommand):
     """Update a given IKE policy."""
 
     resource = 'ikepolicy'
-    log = logging.getLogger(__name__ + '.UpdateIKEPolicy')
 
     def add_known_arguments(self, parser):
         parser.add_argument(
@@ -134,4 +125,3 @@ class DeleteIKEPolicy(neutronv20.DeleteCommand):
     """Delete a given IKE policy."""
 
     resource = 'ikepolicy'
-    log = logging.getLogger(__name__ + '.DeleteIKEPolicy')
